==> jc-1.4.0.tar.gz: soot/jimple/toolkits/base/Zone.h <==
// public class soot.jimple.toolkits.base.Zone

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1eb0eb5572a2a3f4 soot_jimple_toolkits_base_Zone

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_base_Zone_H_
#define _JC_soot_jimple_toolkits_base_Zone_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_base_Zone$sub_refs	_jc_soot_jimple_toolkits_base_Zone$sub_refs;
typedef struct _jc_soot_jimple_toolkits_base_Zone$sub_nonrefs	_jc_soot_jimple_toolkits_base_Zone$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Zone$refs	_jc_soot_jimple_toolkits_base_Zone$refs;
typedef struct _jc_soot_jimple_toolkits_base_Zone$nonrefs	_jc_soot_jimple_toolkits_base_Zone$nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Zone$object	_jc_soot_jimple_toolkits_base_Zone$object;

typedef const struct _jc_soot_jimple_toolkits_base_Zone$vmethods	_jc_soot_jimple_toolkits_base_Zone$vmethods;
typedef const struct _jc_soot_jimple_toolkits_base_Zone$vtable	_jc_soot_jimple_toolkits_base_Zone$vtable;
typedef const struct _jc_soot_jimple_toolkits_base_Zone$vtype	_jc_soot_jimple_toolkits_base_Zone$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_base_Zone$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zone$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_base_Zone$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zone$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_base_Zone$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_base_Zone$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zone$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_base_Zone$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_base_Zone$vmethods	soot_jimple_toolkits_base_Zone;
};

// Vtype
struct _jc_soot_jimple_toolkits_base_Zone$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_base_Zone$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Zone$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Zone$refs {
    _jc_soot_jimple_toolkits_base_Zone$sub_refs	soot_jimple_toolkits_base_Zone;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Zone$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Zone$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_base_Zone$sub_nonrefs	soot_jimple_toolkits_base_Zone;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_base_Zone$object {
	_jc_soot_jimple_toolkits_base_Zone$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_base_Zone$vtype	*vtype;
	_jc_soot_jimple_toolkits_base_Zone$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_base_Zone$vtype _jc_soot_jimple_toolkits_base_Zone$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_base_Zone, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_base_Zone$class_object;

#endif	/* _JC_soot_jimple_toolkits_base_Zone_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/base/Zone.h <==
// public class soot.jimple.toolkits.base.Zone

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1eb0eb5572a2a3f4 soot_jimple_toolkits_base_Zone

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_base_Zone_H_
#define _JC_soot_jimple_toolkits_base_Zone_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_base_Zone$sub_refs	_jc_soot_jimple_toolkits_base_Zone$sub_refs;
typedef struct _jc_soot_jimple_toolkits_base_Zone$sub_nonrefs	_jc_soot_jimple_toolkits_base_Zone$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Zone$refs	_jc_soot_jimple_toolkits_base_Zone$refs;
typedef struct _jc_soot_jimple_toolkits_base_Zone$nonrefs	_jc_soot_jimple_toolkits_base_Zone$nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Zone$object	_jc_soot_jimple_toolkits_base_Zone$object;

typedef const struct _jc_soot_jimple_toolkits_base_Zone$vmethods	_jc_soot_jimple_toolkits_base_Zone$vmethods;
typedef const struct _jc_soot_jimple_toolkits_base_Zone$vtable	_jc_soot_jimple_toolkits_base_Zone$vtable;
typedef const struct _jc_soot_jimple_toolkits_base_Zone$vtype	_jc_soot_jimple_toolkits_base_Zone$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_base_Zone$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zone$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_base_Zone$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zone$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_base_Zone$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_base_Zone$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_base_Zone$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_base_Zone$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_base_Zone$vmethods	soot_jimple_toolkits_base_Zone;
};

// Vtype
struct _jc_soot_jimple_toolkits_base_Zone$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_base_Zone$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Zone$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Zone$refs {
    _jc_soot_jimple_toolkits_base_Zone$sub_refs	soot_jimple_toolkits_base_Zone;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Zone$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Zone$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_base_Zone$sub_nonrefs	soot_jimple_toolkits_base_Zone;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_base_Zone$object {
	_jc_soot_jimple_toolkits_base_Zone$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_base_Zone$vtype	*vtype;
	_jc_soot_jimple_toolkits_base_Zone$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_base_Zone$vtype _jc_soot_jimple_toolkits_base_Zone$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_base_Zone, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_base_Zone$class_object;

#endif	/* _JC_soot_jimple_toolkits_base_Zone_H_ */
